function [pP,roi] = wc_Phisto(wc,roi,varargin)

% wc_Phisto takes P from struct output from wcQ or similar as input and outputs histogram
% of mean P-values, i.e., change probabilities for region of interest, roi
%
% wc_Phisto(wcQ.P,roi); % wcQ is output from wc_Q
% wc_Phisto(wcQ,roi,txt);
% wc_Phisto(wcQR(2),roi,txt); % wcQR is output from wcRjl
% wc_Phisto(P,roi);
%
% input P is P from wc_Q or wishart_change_Q, roi (logical) is region of interest
%   if roi is colour image, draw ROI with colour image as backdrop
%
% pP contains mean, median and entropy measures Shannon, Gini, Rényi
% entropy measures flatness of histogram (flat is 1, one peak is 0)

% mean (1-P)-values, i.e., no-change probabilities for region of interest, roi

% (c) Copyright 2023
% Allan Aasbjerg Nielsen, PhD
% alan@dtu.dk, http://people.compute.dtu.dk/alan
% 1-8 Nov 2023

if nargin<2
    error('wc_Phisto: wrong input')
end
if nargin>4
    error('wc_Phisto: wrong input')
end

if ~isstruct(wc)
    aux = wc;
    clear wc
    wc.P = aux;
    clear aux
end

if ~ismatrix(roi)
    figure, roi = roipolysarrgb(roi);
end

idx = 1;
if nargin==4
    idx = varargin{2};
end

wcnew = wc(1);
if isfield(wc(1),'P')
    wcnew.P = wc(1).P(:,:,idx);
end
clear wc

if size(wcnew.P) ~= size(roi)
    error('wc_Phisto: image and roi must be same size')
end

txt = "";
if nargin>2
    txt = varargin{1};
end
        
% change probability
Paux = wcnew.P(roi);
% % no-change probability
% Paux = 1 - P(roi);
% figure,imshow(Paux.*(1-double(roi)),[0 1])
figure('Name',txt)
hh = histogram(Paux,0:0.05:1);
% hh = histogram(Paux,0:0.05:1,'Normalization','pdf');
grid on
aux = hh.Values/hh.NumBins;
probs = aux/nansum(aux);
shannon = -nansum(probs.*log(probs))/log(hh.NumBins);
gini = nansum(probs.*(1-probs));
gini = gini*hh.NumBins/(hh.NumBins-1); % norm to max 1
renyi = -log(nansum(probs.*probs))/log(hh.NumBins);
pP = [mean(Paux), median(Paux), shannon, gini, renyi];
fprintf('mean = %f, median = %f, Shannon = %f, Gini = %f Rényi = %f\n', ...
    mean(Paux), median(Paux), shannon, gini, renyi)
